@@ -16,15 +16,9 @@ fast_mqtt = FastMQTT(
 app = FastAPI()
 
 
-@app.on_event("startup")
-async def startapp():
-    await fast_mqtt.connection()
+fast_mqtt.init_app(app)
 
 
-@app.on_event("shutdown")
-async def shutdown():
-    await fast_mqtt.client.disconnect()
-
 @fast_mqtt.on_connect()
 def connect(client, flags, rc, properties):
     fast_mqtt.client.subscribe("/WILL") #/WILL will trigger after disconnect 
